"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.OpenAPISchemaValidator = void 0;
const ajv_1 = require("ajv");
const ajv_formats_1 = require("ajv-formats");
// https://github.com/OAI/OpenAPI-Specification/blob/master/schemas/v3.0/schema.json
const openapi3Schema = require("./openapi.v3.schema.json");
class OpenAPISchemaValidator {
    constructor(opts) {
        const options = {
            allErrors: true,
            strictTypes: false
        };
        if (!opts.validateApiSpec) {
            options.validateSchema = false;
        }
        const ajv = new ajv_1.default(options);
        ajv_formats_1.default(ajv);
        // v.addMetaSchema(draftSchema);
        const ver = opts.version && parseInt(String(opts.version), 10);
        if (!ver)
            throw Error('version missing from OpenAPI specification');
        if (ver != 3)
            throw Error('OpenAPI v3 specification version is required');
        ajv.addSchema(openapi3Schema);
        this.validator = ajv.compile(openapi3Schema);
    }
    validate(openapiDoc) {
        const valid = this.validator(openapiDoc);
        if (!valid) {
            return { errors: this.validator.errors };
        }
        else {
            return { errors: [] };
        }
    }
}
exports.OpenAPISchemaValidator = OpenAPISchemaValidator;
//# sourceMappingURL=openapi.schema.validator.js.map