"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.OpenApiValidator = void 0;
const ono_1 = require("ono");
const openapi_request_validator_1 = require("./middlewares/openapi.request.validator");
const openapi_context_1 = require("./framework/openapi.context");
const base_serdes_1 = require("./framework/base.serdes");
const schema_preprocessor_1 = require("./middlewares/parsers/schema.preprocessor");
const options_1 = require("./framework/ajv/options");
const cloneDeep = require("lodash.clonedeep");
const openapi_spec_loader_1 = require("./framework/openapi.spec.loader");
class OpenApiValidator {
    constructor(options) {
        this.validateOptions(options);
        this.normalizeOptions(options);
        if (options.validateRequests == null)
            options.validateRequests = true;
        if (options.formats == null)
            options.formats = [];
        if (options.validateRequests === true) {
            options.validateRequests = {
                allowUnknownQueryParameters: false
            };
        }
        this.options = options;
        this.ajvOpts = new options_1.AjvOptions(options);
    }
    createValidator() {
        const specAsync = new openapi_spec_loader_1.OpenApiSpecLoader({ apiDoc: cloneDeep(this.options.apiSpec), validateApiSpec: this.options.validateApiSpec }).load();
        let requestValidator;
        return async (request) => {
            if (!requestValidator) {
                const spec = await specAsync;
                const apiDoc = spec.apiDoc;
                const ajvOpts = this.ajvOpts.preprocessor;
                const sp = new schema_preprocessor_1.SchemaPreprocessor(apiDoc, ajvOpts).preProcess();
                const context = new openapi_context_1.OpenApiContext(spec, this.options.ignorePaths);
                requestValidator = new openapi_request_validator_1.RequestValidator(context.apiDoc, this.ajvOpts.request);
            }
            requestValidator.validate(request);
        };
    }
    validateOptions(options) {
        if (!options.apiSpec)
            throw ono_1.default('apiSpec required');
    }
    normalizeOptions(options) {
        if (!options.serDes) {
            options.serDes = base_serdes_1.defaultSerDes;
        }
        else {
            base_serdes_1.defaultSerDes.forEach((currentDefaultSerDes) => {
                let defaultSerDesOverride = options.serDes.find((currentOptionSerDes) => {
                    return currentDefaultSerDes.format === currentOptionSerDes.format;
                });
                if (!defaultSerDesOverride) {
                    options.serDes.push(currentDefaultSerDes);
                }
            });
        }
    }
}
exports.OpenApiValidator = OpenApiValidator;
//# sourceMappingURL=index.js.map